@@ -375,7 +375,7 @@ class Command(PatchedTemplateCommand):
                 {strategy_help} 
                 """
             ),
-            default=ImplementationStrategy.SYNC_BASE_FUNCTION.key,
+            required=True,
         )
 
         parser.add_argument(
