@@ -72,10 +72,13 @@ class EntityStorage:
 
         self._checked_application_paths: List[Path] = []
 
-        self._entity_module_patterns: List[str] = [
-            f'**/**/{model_enum_value.module}.py'
-            for model_enum_value in EntityType.get_model_enum_values()
-        ]
+        self._entity_module_patterns: List[str] = []
+
+        for model_enum_value in EntityType.get_model_enum_values():
+            self._entity_module_patterns.extend([
+                f'**/**/{model_enum_value.module}.py',
+                f'**/**/{model_enum_value.module}.pyc',
+            ])
 
         self._entities_modules: List[Tuple[Path, str, ModuleType]] = []
 
